==> haskell-fingertree-0.1.2.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.2.1
id: fingertree-0.1.2.1-AdW3qo2F87f3RmpO72aWjC
key: fingertree-0.1.2.1-AdW3qo2F87f3RmpO72aWjC
license: BSD3
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
exposed: True
indefinite: False
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
abi: 2832d847d798e4aee2b62e217d1c4d65
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/fingertree-0.1.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/fingertree-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/fingertree-0.1.2.1
hs-libraries: HSfingertree-0.1.2.1-AdW3qo2F87f3RmpO72aWjC
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.3.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fingertree
version: 0.1.3.0
id: fingertree-0.1.3.0-9o4ycm73djS77gzlfTCIs4
key: fingertree-0.1.3.0-9o4ycm73djS77gzlfTCIs4
license: BSD3
copyright: (c) 2006 Ross Paterson, Ralf Hinze
maintainer: Ross Paterson <R.Paterson@city.ac.uk>
synopsis: Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of
    .
    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>
    .
    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.
category: Data Structures
exposed: True
indefinite: False
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree
abi: 869972a334e3a2ac2088a86e93620288
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/fingertree-0.1.3.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/fingertree-0.1.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/fingertree-0.1.3.0
hs-libraries: HSfingertree-0.1.3.0-9o4ycm73djS77gzlfTCIs4
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html: /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
